@@ -16,7 +16,7 @@ import sys, select, traceback
 
 # Import TaskQueue and Task, preferring built-in C code over Python code
 try:
-    from _uasyncio import TaskQueue, Task
+    from _asyncio import TaskQueue, Task
 except:
     from .task import TaskQueue, Task
 
